#
#	File:		IW-Half-Dither.make
#
#	Contains:	Makefile for the sample ImageWriter II driver.
#
#	Copyright:	 1983-1996 by Apple Computer, Inc., all rights reserved.
#
#	Change History (most recent first):
#
#
#				05/21/96	Don Swatman	Modifications for halftoning, dithering and plane seperations.
#				05/21/96	Jason H-H	Updated for ETO#19/MW.
#				 8/26/94	dmh		Finalized.
#				 3/22/94	dmh		Modified for the b4 seed.
#				12/18/93	dmh		Modified for the b3 seed.
#				 9/12/93	dmh		Modified for the b2 seed.
#				 4/26/93	dmh		Modified for the b1 seed.
#				 2/04/93	dmh		Modified for the a5 seed.
#		 <5>	10/22/92	DB		Added changes for version control
#
#

#======= Point these variables to your interface and library directories =======

GXLibrariesSources	=	"{MPW}Libraries:GX Libraries:"

#========== Directories Containing Source and Object Files ==========

ObjDir					=	:Objects:
SrcDir					=	:source:
DestDir					=	

#========== Compiler Options ==========

AsmOptions				=	-case obj
RezOptions				=	-i "{Rincludes}" -d SystemSevenOrLater=1
COptions				=	-d applec -b2 -i "{cIncludes}" -i {GXLibrariesSources}
LinkOptions				=	-ra =resSysHeap,resPurgeable
SC						=	C

DriverName 		= "IW-Half-Dither"
DriverType 		= 'pdvr'
DriverCreator 	= 'Dipy'
NewSegID		= 0
OldSegID		= 1

# Compile and assemble statements
{ObjDir}OldApp.c.o  {SrcDir}OldApp.c {SrcDir}CommonDefines.h
	Echo "{DriverName}: Compiling old application"
	{C} {COptions} -o {ObjDir} {SrcDir}OldApp.c

{ObjDir}OldApp.a.o	 	{SrcDir}OldApp.a
	Echo "{DriverName}: Assembling old app jump table"
	Asm {AsmOptions} {MakeJumpTable} {SrcDir}OldApp.a -o {ObjDir}

{ObjDir}NewApp.c.o	 {SrcDir}NewApp.c {SrcDir}CommonDefines.h
	Echo "{DriverName}: Compiling new application"
	{C} {COptions} -o {ObjDir} {SrcDir}NewApp.c

{ObjDir}NewApp.a.o	 	{SrcDir}NewApp.a
	Echo "{DriverName}: Assembling new app jump table"
	Asm {AsmOptions} {MakeJumpTable} {SrcDir}NewApp.a -o {ObjDir}

{ObjDir}ChooserSupportLDEF.c.o	 {SrcDir}ChooserSupportLDEF.c {SrcDir}CommonDefines.h
	Echo "{DriverName}: Compiling Chooser support"
	{C} {COptions} -o {ObjDir} {SrcDir}ChooserSupportLDEF.c

{ObjDir}ChooserSupportPACK.c.o	 {SrcDir}ChooserSupportPACK.c {SrcDir}CommonDefines.h
	Echo "{DriverName}: Compiling Chooser support"
	{C} {COptions} -o {ObjDir} {SrcDir}ChooserSupportPACK.c

{ObjDir}ChooserSupport.a.o	 	{SrcDir}ChooserSupport.a
	Echo "{DriverName}: Assembling Chooser support"
	Asm {AsmOptions} {MakeJumpTable} {SrcDir}ChooserSupport.a -o {ObjDir}

# Link and Rez statements
{DestDir}{DriverName}  {SrcDir}OldApp.r {SrcDir}CommonDefines.h
	 Echo "{DriverName}: Rezzing old application"
	 Rez {RezOptions} -append -o {DestDir}{DriverName} {SrcDir}OldApp.r
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}
		
{DestDir}{DriverName}  {ObjDir}OldApp.c.o
	Echo "{DriverName}: Linking old application"
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

"{ObjDir}TextLibrary.c.o"		 {GXLibrariesSources}TextLibrary.c
	Echo "compiling TextLibrary.c"
	{C} {COptions} -o {ObjDir} {GXLibrariesSources}TextLibrary.c

"{ObjDir}PictureLibrary.c.o"	 {GXLibrariesSources}PictureLibrary.c
	Echo "compiling PictureLibrary.c"
	{C} {COptions} -o {ObjDir} {GXLibrariesSources}PictureLibrary.c

"{ObjDir}ColorLibrary.c.o"		 {GXLibrariesSources}ColorLibrary.c
	Echo "compiling ColorLibrary.c"
	{C} {COptions} -o {ObjDir} {GXLibrariesSources}ColorLibrary.c

"{ObjDir}GraphicsLibrary.c.o"	 {GXLibrariesSources}GraphicsLibrary.c
	Echo "compiling GraphicsLibrary.c"
	{C} {COptions} -o {ObjDir} {GXLibrariesSources}GraphicsLibrary.c

{DestDir}{DriverName}  {SrcDir}NewApp.r {SrcDir}CommonDefines.h
	 Echo "{DriverName}: Rezzing new application"
	 Rez {RezOptions} -append -o {DestDir}{DriverName} {SrcDir}NewApp.r
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  						
	{ObjDir}NewApp.a.o							
	{ObjDir}NewApp.c.o							
		"{ObjDir}TextLibrary.c.o"				
		"{ObjDir}PictureLibrary.c.o"			
		"{ObjDir}ColorLibrary.c.o"				
		"{ObjDir}GraphicsLibrary.c.o"			
	Echo "{DriverName}: linking new API"
	Link										
		-rt {DriverType}={NewSegID}				
		-c {DriverCreator}						
		-t {DriverType}							
		-sg {DriverName}						
		-m SD_JumpTable							
		-o {DestDir}{DriverName}				
		{ObjDir}NewApp.a.o						
		{ObjDir}NewApp.c.o						
		"{ObjDir}TextLibrary.c.o"				
		"{ObjDir}PictureLibrary.c.o"			
		"{ObjDir}ColorLibrary.c.o"				
		"{ObjDir}GraphicsLibrary.c.o"			
		"{Libraries}Interface.o" 				
		"{Libraries}MacRuntime.o"	 			
		{LinkOptions}							
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  						
	{ObjDir}OldApp.a.o							
	{ObjDir}OldApp.c.o
	Echo "{DriverName}: linking old API"
	Link										
		-rt {DriverType}={OldSegID}				
		-c {DriverCreator}						
		-t {DriverType}							
		-sg {DriverName}						
		-m SD_JumpTable							
		-o {DestDir}{DriverName}				
		{ObjDir}OldApp.a.o						
		{ObjDir}OldApp.c.o						
		"{Libraries}MacRuntime.o" 				
		"{Libraries}Interface.o"	 			
		{LinkOptions}							
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  {SrcDir}ChooserSupport.r {SrcDir}CommonDefines.h
	Echo "{DriverName}: Rezzing Chooser resources"
	Rez {RezOptions} -append -o {DestDir}{DriverName} {SrcDir}ChooserSupport.r
	SetFile -a Bi -t {DriverType} -c {DriverCreator} {DestDir}{DriverName}

{DestDir}{DriverName}  						
	{ObjDir}ChooserSupport.a.o					
	{ObjDir}ChooserSupportPACK.c.o
	Echo "{DriverName}: Linking PACK"
	Link										
		-ra =resSysHeap,resPurgeable			
		-rt PACK=-4096							
		-sg PrintingPACK						
		-m EntryPoint							
		-o {Targ}								
		{ObjDir}ChooserSupport.a.o				
		{ObjDir}ChooserSupportPACK.c.o				

{DestDir}{DriverName}	 {ObjDir}ChooserSupportLDEF.c.o
	Echo "{DriverName}: Linking LDEF"
	Link -w -ra =resSysHeap,resPurgeable		
			-rt LDEF=-4096 -sg LDEF		
			-o {Targ} {ObjDir}ChooserSupportLDEF.c.o
